@@ -1,6 +1,6 @@
 package Reddit::Client;
 
-our $VERSION = '1.093'; 
+our $VERSION = '1.094'; 
 $VERSION = eval $VERSION;
 
 use strict;
@@ -96,6 +96,7 @@ use constant API_CREATEMULTI         => 26;
 use constant API_DELETEMULTI         => 27;
 use constant API_GETMULTI            => 28;
 use constant API_EDITMULTI           => 29;
+use constant API_SUBREDDIT_INFO      => 30;
 
 #===============================================================================
 # Parameters
@@ -139,6 +140,7 @@ $API[API_CREATEMULTI   ] = ['POST', '/api/multi/user/%s/m/%s' ];
 $API[API_GETMULTI      ] = ['GET', '/api/multi/user/%s/m/%s%s'];
 $API[API_DELETEMULTI   ] = ['DELETE','/api/multi/user/%s/m/%s'];
 $API[API_EDITMULTI     ] = ['PUT',  '/api/multi/user/%s/m/%s' ];
+$API[API_SUBREDDIT_INFO] = ['GET',  '/r/%s/about'             ];
 #===============================================================================
 # Package routines
 #===============================================================================
@@ -473,6 +475,18 @@ sub mark_inbox_read {
 # Subreddits and listings
 #===============================================================================
 
+sub get_subreddit_info {
+	my $self	= shift;
+	my $sub		= shift || croak 'Argument 1 (subreddit name) is required.';
+	$sub = subreddit($sub);
+
+	my $result = $self->api_json_request(
+		api 	=> API_SUBREDDIT_INFO,
+		args	=> [$sub],
+	);
+	return $result->{data};
+}
+
 sub info {
     my ($self, $id) = @_;
     DEBUG('Get info for id %s', $id);
